==> mlmmj_1.2.18.0.orig.tar.gz: mlmmj-1.2.18.0/include/do_all_the_voodoo_here.h <==
/* Copyright (C) 2004 Mads Martin Joergensen <mmj at mmj.dk>
 *
 * $Id$
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#ifndef DO_ALL_THE_VOODOO_HERE_H
#define DO_ALL_THE_VOODOO_HERE_H

#include "mlmmj.h" /* For struct mailhdr and struct strlist */

int findit(const char *line, const char **headers);
void getinfo(const char *line, struct mailhdr *readhdrs);
int do_all_the_voodoo_here(int infd, int outfd, int hdrfd, int footfd,
	      const char **delhdrs, struct mailhdr *readhdrs,
	      struct strlist *allhdrs, const char *subjectprefix);

#endif /* DO_ALL_THE_VOODOO_HERE_H */

==> mlmmj_1.3.0.orig.tar.gz: mlmmj-1.3.0/include/do_all_the_voodoo_here.h <==
/* Copyright (C) 2004 Mads Martin Joergensen <mmj at mmj.dk>
 *
 * $Id$
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

#ifndef DO_ALL_THE_VOODOO_HERE_H
#define DO_ALL_THE_VOODOO_HERE_H

#include "mlmmj.h" /* For struct mailhdr and struct strlist */

int findit(const char *line, const struct strlist *headers);
void getinfo(const char *line, struct mailhdr *readhdrs);
int do_all_the_voodoo_here(int infd, int outfd, int hdrfd, int footfd,
	      const struct strlist *delhdrs, struct mailhdr *readhdrs,
	      struct strlist *allhdrs, const char *subjectprefix);

#endif /* DO_ALL_THE_VOODOO_HERE_H */
